@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date : October 2009
 # Version 0.9
 # Licence GPL v3
@@ -52,7 +52,7 @@
 	x@file@offset <- dfoffset
 	x@file@toptobottom <- toptobottom
 
-	if (nchar(layernames) > 1) {
+	if (.nchar(layernames) > 1) {
 		lnams <- unlist(strsplit(layernames, ':'))
 	} else {
 		lnams <- gsub(" ", "_", extension(basename(filename), ""))
